@@ -64,7 +64,7 @@ public:
 private:
     Preferences *m_pPanprefs;
     QColor *m_pLight, *m_pDark;
-    QColorGroup *m_pOrigcolours;
+    QColorGroup *m_pOrigcolours, *m_pAltcolours;
 
 public:
     QGroupBox *m_pGenbox, *m_pRembox, *m_pShadebox, *m_pThemebox;
@@ -117,6 +117,8 @@ public:
     QColor *getDark(void)      {return m_pDark;};
     QColor *getRevlight(void)  {return (QColor *)&m_pOrigcolours->foreground();};
     QColor *getRevdark(void)   {return (QColor *)&m_pOrigcolours->background();};
+    QColor *getAltlight(void)  {return (QColor *)&m_pAltcolours->foreground();};
+    QColor *getAltdark(void)   {return (QColor *)&m_pAltcolours->background();};
 
     // Accessor set methods
     void setAccounts(const QString &kInstr)  {m_pAcctline->setText(kInstr);};
@@ -134,6 +136,7 @@ public:
     void setLight(const QColor *pLight)           {m_pLight = (QColor *)pLight;};
     void setDark(const QColor *pDark)             {m_pDark = (QColor *)pDark;};
     void setOrigcolour(QColorGroup *pGroup)       {m_pOrigcolours = pGroup;};
+    void setAltcolour(QColorGroup *pGroup)        {m_pAltcolours  = pGroup;};
     void setCorbaon(const bool &kbEnable = true)  {
         m_pCorbaline->setEnabled(kbEnable);
         m_pCorbacheck->setChecked(kbEnable);
